@@ -12,7 +12,7 @@ wrapper: Py3cwClosure = None
 
 @logged
 @with_py3cw
-def get():
+def get(payload: dict = None):
     """
     GET /ver1/deals
     User deals (Permission: BOTS_READ, Security: SIGNED)
@@ -21,13 +21,14 @@ def get():
     error, data = wrapper.request(
         entity='deals',
         action='',
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_convert_to_smart_trade_by_id(deal_id):
+def post_convert_to_smart_trade_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/convert_to_smart_trade
     Convert to smart trade (Permission: SMART_TRADE_WRITE, Security: SIGNED)
@@ -36,14 +37,15 @@ def post_convert_to_smart_trade_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='convert_to_smart_trade',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_update_max_safety_orders_by_id(deal_id):
+def post_update_max_safety_orders_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/update_max_safety_orders
     Update max safety orders (Permission: BOTS_WRITE, Security: SIGNED)
@@ -52,14 +54,15 @@ def post_update_max_safety_orders_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='update_max_safety_orders',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_panic_sell_by_id(deal_id):
+def post_panic_sell_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/panic_sell
     Panic sell deal (Permission: BOTS_WRITE, Security: SIGNED)
@@ -68,14 +71,15 @@ def post_panic_sell_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='panic_sell',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_cancel_by_id(deal_id):
+def post_cancel_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/cancel
     Cancel deal (Permission: BOTS_WRITE, Security: SIGNED)
@@ -84,14 +88,15 @@ def post_cancel_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='cancel',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def patch_update_deal_by_id(deal_id):
+def patch_update_deal_by_id(id, payload: dict = None):
     """
     PATCH /ver1/deals/{deal_id}/update_deal
     Update deal (Permission: BOTS_WRITE, Security: SIGNED)
@@ -100,14 +105,15 @@ def patch_update_deal_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='update_deal',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_update_tp_by_id(deal_id):
+def post_update_tp_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/update_tp
     DEPRECATED, Update take profit condition. Deal status should be bought (Permission: BOTS_WRITE, Security: SIGNED)
@@ -116,14 +122,15 @@ def post_update_tp_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='update_tp',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get_show_by_id(deal_id):
+def get_show_by_id(id, payload: dict = None):
     """
     GET /ver1/deals/{deal_id}/show
     Info about specific deal (Permission: BOTS_READ, Security: SIGNED)
@@ -132,14 +139,15 @@ def get_show_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='show',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_cancel_order_by_id(deal_id):
+def post_cancel_order_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/cancel_order
     Cancel manual safety orders (Permission: BOTS_WRITE, Security: SIGNED)
@@ -148,14 +156,15 @@ def post_cancel_order_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='cancel_order',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get_market_orders_by_id(deal_id):
+def get_market_orders_by_id(id, payload: dict = None):
     """
     GET /ver1/deals/{deal_id}/market_orders
     Deal safety orders (Permission: BOTS_READ, Security: SIGNED)
@@ -164,14 +173,15 @@ def get_market_orders_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='market_orders',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def post_add_funds_by_id(deal_id):
+def post_add_funds_by_id(id, payload: dict = None):
     """
     POST /ver1/deals/{deal_id}/add_funds
     Adding manual safety order (Permission: BOTS_WRITE, Security: SIGNED)
@@ -180,14 +190,15 @@ def post_add_funds_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='add_funds',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
 
 @logged
 @with_py3cw
-def get_data_for_adding_funds_by_id(deal_id):
+def get_data_for_adding_funds_by_id(id, payload: dict = None):
     """
     GET /ver1/deals/{deal_id}/data_for_adding_funds
     Info required to add funds correctly: available amounts, exchange limitations etc  (Permission: BOTS_READ, Security: SIGNED)
@@ -196,7 +207,8 @@ def get_data_for_adding_funds_by_id(deal_id):
     error, data = wrapper.request(
         entity='deals',
         action='data_for_adding_funds',
-        action_id=str(deal_id),
+        action_id=str(id),
+        payload=payload,
     )
     return ThreeCommasApiError(error), data
 
